DevCsi

Struct DevCsi 

pub struct DevCsi { /* private fields */ }
A Csi implementation that can be used for testing within normal Rust targets.

Implementations

Source

impl DevCsi

pub fn new(address: impl Into<String>, token: impl Into<String>) -> Self

pub fn aleph_alpha(token: impl Into<String>) -> Self

Construct a new DevCsi that points to the Aleph Alpha hosted Kernel